==> haskell-blaze-markup-0.8.2.0-9-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-blaze-markup.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: blaze-markup
version: 0.8.2.0
id: blaze-markup-0.8.2.0-GCcEZDymsJc2Skqtj6a7Q3
key: blaze-markup-0.8.2.0-GCcEZDymsJc2Skqtj6a7Q3
license: BSD3
maintainer: Jasper Van der Jeugt <m@jaspervdj.be>
stability: Experimental
homepage: http://jaspervdj.be/blaze
synopsis: A blazingly fast markup combinator library for Haskell
description:
    Core modules of a blazingly fast markup combinator library for the Haskell
    programming language. The Text.Blaze module is a good
    starting point, as well as this tutorial:
    <http://jaspervdj.be/blaze/tutorial.html>.
category: Text
author: Jasper Van der Jeugt, Simon Meier, Deepak Jois
exposed: True
indefinite: False
exposed-modules:
    Text.Blaze Text.Blaze.Internal Text.Blaze.Renderer.Pretty
    Text.Blaze.Renderer.String Text.Blaze.Renderer.Text
    Text.Blaze.Renderer.Utf8
abi: 89f2a92574468b60b114253ec4e21006
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/blaze-markup-0.8.2.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/blaze-markup-0.8.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/blaze-markup-0.8.2.0
hs-libraries: HSblaze-markup-0.8.2.0-GCcEZDymsJc2Skqtj6a7Q3
depends:
    base-4.10.1.0 blaze-builder-0.4.1.0-7NuHBr78TbA3v0KunGhGI7
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz bytestring-0.10.8.2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             blaze-builder-0.4.1.0-7NuHBr78TbA3v0KunGhGI7=3e7866bdfc4c145dc5858d744aeae7aa
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
haddock-interfaces: /usr/share/doc/haskell-blaze-markup/html/blaze-markup.haddock
haddock-html: /usr/share/doc/haskell-blaze-markup/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-blaze-markup-0.8.2.1-12-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-blaze-markup.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: blaze-markup
version: 0.8.2.1
id: blaze-markup-0.8.2.1-FFkiru1HsegAfMrnqJMDug
key: blaze-markup-0.8.2.1-FFkiru1HsegAfMrnqJMDug
license: BSD-3-Clause
maintainer: Jasper Van der Jeugt <m@jaspervdj.be>
author: Jasper Van der Jeugt, Simon Meier, Deepak Jois
stability: Experimental
homepage: http://jaspervdj.be/blaze
synopsis: A blazingly fast markup combinator library for Haskell
description:
    Core modules of a blazingly fast markup combinator library for the Haskell
    programming language. The Text.Blaze module is a good
    starting point, as well as this tutorial:
    <http://jaspervdj.be/blaze/tutorial.html>.
category: Text
abi: 71b515c6e3bfb99ff0075cc129b1fc3b
exposed: True
exposed-modules:
    Text.Blaze Text.Blaze.Internal Text.Blaze.Renderer.Pretty
    Text.Blaze.Renderer.String Text.Blaze.Renderer.Text
    Text.Blaze.Renderer.Utf8
import-dirs: /usr/lib/ghc-8.4.3/site-local/blaze-markup-0.8.2.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/blaze-markup-0.8.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/blaze-markup-0.8.2.1
hs-libraries: HSblaze-markup-0.8.2.1-FFkiru1HsegAfMrnqJMDug
depends:
    base-4.11.1.0 blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028
    text-1.2.3.0 bytestring-0.10.8.2
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028=f952a1ec5abae3e4435518edbfd82e4e
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
haddock-interfaces: /usr/share/doc/haskell-blaze-markup/html/blaze-markup.haddock
haddock-html: /usr/share/doc/haskell-blaze-markup/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
